@@ -160,9 +160,7 @@ Returns the client-supplied Content-Type.
 
 =head1 AUTHORS
 
-Sebastian Riedel, C<sri@cpan.org>
-
-Christian Hansen, C<ch@ngmedia.com>
+Catalyst Contributors, see Catalyst.pm
 
 =head1 COPYRIGHT
 
